==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/base/keycodes_8h.js <==
var keycodes_8h =
[
    [ "KeyCode", "structSteinberg_1_1KeyCode.html", "structSteinberg_1_1KeyCode" ],
    [ "VirtualKeyCodes", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22b", [
      [ "KEY_BACK", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba363a5589e96b18dca6534e951baffdd3", null ],
      [ "KEY_TAB", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba60c75f9c8eded88ef76c0c94da27963c", null ],
      [ "KEY_CLEAR", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baee7181a798c5753153051c0e1ace41c9", null ],
      [ "KEY_RETURN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baaefd064b1e5d75c429bed314ac18eba0", null ],
      [ "KEY_PAUSE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad26d172dc2cd90741c3939ca4fab0b84", null ],
      [ "KEY_ESCAPE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3a471c8b61a5f730dcbdd50fe53f3ab7", null ],
      [ "KEY_SPACE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba01d2889f9a7550008ad6140c41e733de", null ],
      [ "KEY_NEXT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba82d61b2ebb1c5fee25aea8d69d325acc", null ],
      [ "KEY_END", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa8adb6fcb92dec58fb19410eacfdd403", null ],
      [ "KEY_HOME", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad5b83418c285e43af5d3a87b4d4049d7", null ],
      [ "KEY_LEFT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba612120b69c7dfd46086db7aaebdbcf65", null ],
      [ "KEY_UP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba0848a442d907968b211b97bc2bd88acd", null ],
      [ "KEY_RIGHT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6504370d9c6391e1a9da6a1a529b089d", null ],
      [ "KEY_DOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa9cdac7967bf7d88fdb761138a2a3416", null ],
      [ "KEY_PAGEUP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5d9c9ba1d8f2c6f6737db37d3f449071", null ],
      [ "KEY_PAGEDOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5996c34d86df2b3c1be741aeb35bdbc4", null ],
      [ "KEY_SELECT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3b37a163628bc7015aac5efab4a66ef5", null ],
      [ "KEY_PRINT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf6ff54b9651ca18045e4000c2d26f790", null ],
      [ "KEY_ENTER", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba2a662d23aadd7106a3a2afdfd5d426ed", null ],
      [ "KEY_SNAPSHOT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bacc39d60a35433541177dbd7bf01a8257", null ],
      [ "KEY_INSERT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba26f2c18a3a0a7eabf7bd11f0ec93be78", null ],
      [ "KEY_DELETE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae7a3a4540031b038014294aa6743a7a4", null ],
      [ "KEY_HELP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad729e81b40a3acb64b5a40b7fa459b09", null ],
      [ "KEY_NUMPAD0", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba55aef83f557c4ed24e2847d38ea292b3", null ],
      [ "KEY_NUMPAD1", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba681b5574363c5d5a463af7e514172292", null ],
      [ "KEY_NUMPAD2", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba779490ca3da209736187a912cd8382dc", null ],
      [ "KEY_NUMPAD3", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae58753ec4558e7b68f4aa07ed97d50d7", null ],
      [ "KEY_NUMPAD4", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba744226502b73227ed219a5142c232126", null ],
      [ "KEY_NUMPAD5", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba906fbf3011cae4b931d6fe6126147a82", null ],
      [ "KEY_NUMPAD6", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bac4e7f0a72c3594aa3d5b83f61b714e3f", null ],
      [ "KEY_NUMPAD7", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae6d134db5bf54ae1d4b29f8a2cca8889", null ],
      [ "KEY_NUMPAD8", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba258d226c87d8446423d3214a59eb498b", null ],
      [ "KEY_NUMPAD9", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6ab9d27201ffbdccabde9f5a0e9dedd9", null ],
      [ "KEY_MULTIPLY", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa7ccd4f6c9a10fe36e0e7bd28d15bea3", null ],
      [ "KEY_ADD", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba88535ed64ae437ce31620dcb62c66c9e", null ],
      [ "KEY_SEPARATOR", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba79459423b8bbe9f70949f464cd7a27ae", null ],
      [ "KEY_SUBTRACT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf6ba424919235c2cbbac7184e3625395", null ],
      [ "KEY_DECIMAL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bafce663586a7e53223158c5f4ce6033fc", null ],
      [ "KEY_DIVIDE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba36a890023ae628d5c36ca010edffc59c", null ],
      [ "KEY_F1", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bafcf70bc39c0032de8a1c6452ac9860a5", null ],
      [ "KEY_F2", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba87897fd25282941e1a9bf72b9f64559a", null ],
      [ "KEY_F3", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba965c99b1f4fc05cec09ef61b0af8e74a", null ],
      [ "KEY_F4", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba01bce78a73ad136a7b42941297aff373", null ],
      [ "KEY_F5", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6a69ea34f5d1372692bf040637e57c8f", null ],
      [ "KEY_F6", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba247a20a9998f080827dd34004abc2f9a", null ],
      [ "KEY_F7", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba34a07203a0a4f3e996b44e9a4fcfd1c6", null ],
      [ "KEY_F8", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba9eaf4e9e3d8451fd1332c013d12c1375", null ],
      [ "KEY_F9", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba160e82eea885870bfa4924c27040cd7f", null ],
      [ "KEY_F10", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3b922025c26b38585ab140c7e40b291c", null ],
      [ "KEY_F11", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad54743bc4e7f9279abf671cc2a091ce1", null ],
      [ "KEY_F12", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba835f8397baa58fd73ff9c268d6458add", null ],
      [ "KEY_NUMLOCK", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa98feaa9c2c57dc8e7b04cb8fddc1a61", null ],
      [ "KEY_SCROLL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba10db988ee4f813d95a5b7cd2f96e3c48", null ],
      [ "KEY_SHIFT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba7d538b177ab06797012e9ffb1449acd9", null ],
      [ "KEY_CONTROL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba48f64be40a1a166f83ec1cab14da6bdc", null ],
      [ "KEY_ALT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf22ac608afcf783bb841f664a2620ca6", null ],
      [ "KEY_EQUALS", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf97f0846e149da44bbf962fa75680809", null ],
      [ "KEY_CONTEXTMENU", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba1992687fd833d3503080861864624e25", null ],
      [ "KEY_MEDIA_PLAY", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6322842e54ea558c670690f2715b45fb", null ],
      [ "KEY_MEDIA_STOP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baad3b9b6fd66ddf211586428be4479c43", null ],
      [ "KEY_MEDIA_PREV", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba29d798af827489cf5ab68c378b8a7ac8", null ],
      [ "KEY_MEDIA_NEXT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bac80fc1b18bda12f7dfccbbe1b012798b", null ],
      [ "KEY_VOLUME_UP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baedbb585f9e7ee87263a250c91542fb02", null ],
      [ "KEY_VOLUME_DOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba2304f457aba66febcf852dbf1cbae8b0", null ],
      [ "KEY_F13", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba29161713f30649423d0ddefa16028396", null ],
      [ "KEY_F14", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba7a39de2eb466cf269a7a34d0377cf326", null ],
      [ "KEY_F15", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba57efdf8b5659ceaf5bda4be62e65ab56", null ],
      [ "KEY_F16", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baabf57281e043880eb269a6a72368aca5", null ],
      [ "KEY_F17", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5ce646467129e626c1ec8888f80045ed", null ],
      [ "KEY_F18", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bab6e856fc1ebc35abda65fd30fe9deeca", null ],
      [ "KEY_F19", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa385ff09ff5f05a4fedb1e75570baa8b", null ],
      [ "VKEY_FIRST_CODE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba0abb06f320e406fbe76c08b2f5909ad6", null ],
      [ "VKEY_LAST_CODE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba219b7884c92935dc6365a7fec8b55bcf", null ],
      [ "VKEY_FIRST_ASCII", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba39f030dbc1bfdb4a14a310acc744178f", null ]
    ] ],
    [ "KeyModifier", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493d", [
      [ "kShiftKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da7dee5096e7803ac26cee7abe740d777d", null ],
      [ "kAlternateKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da8779d8eaee888493c6c5db7acc5d4a0a", null ],
      [ "kCommandKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da111880e47a70791b129ec7a46f988078", null ],
      [ "kControlKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da6bd5ac36e7d960d29783e07406f3b15c", null ]
    ] ],
    [ "VirtualKeyCodeToChar", "keycodes_8h.html#aac1c8cc4f206d2342fdd10c5c3d2fc6f", null ],
    [ "CharToVirtualKeyCode", "keycodes_8h.html#af3106a92c99884d4eb8bef6f0f35e4b8", null ],
    [ "isModifierOnlyKey", "keycodes_8h.html#ad183c365a06b5560e86a61439e756a19", null ]
];

==> vst3sdk-docs-3.7.7_build_19-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/base/keycodes_8h.js <==
var keycodes_8h =
[
    [ "KeyCode", "structSteinberg_1_1KeyCode.html", "structSteinberg_1_1KeyCode" ],
    [ "VirtualKeyCodes", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22b", [
      [ "KEY_BACK", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba363a5589e96b18dca6534e951baffdd3", null ],
      [ "KEY_TAB", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba60c75f9c8eded88ef76c0c94da27963c", null ],
      [ "KEY_CLEAR", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baee7181a798c5753153051c0e1ace41c9", null ],
      [ "KEY_RETURN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baaefd064b1e5d75c429bed314ac18eba0", null ],
      [ "KEY_PAUSE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad26d172dc2cd90741c3939ca4fab0b84", null ],
      [ "KEY_ESCAPE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3a471c8b61a5f730dcbdd50fe53f3ab7", null ],
      [ "KEY_SPACE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba01d2889f9a7550008ad6140c41e733de", null ],
      [ "KEY_NEXT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba82d61b2ebb1c5fee25aea8d69d325acc", null ],
      [ "KEY_END", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa8adb6fcb92dec58fb19410eacfdd403", null ],
      [ "KEY_HOME", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad5b83418c285e43af5d3a87b4d4049d7", null ],
      [ "KEY_LEFT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba612120b69c7dfd46086db7aaebdbcf65", null ],
      [ "KEY_UP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba0848a442d907968b211b97bc2bd88acd", null ],
      [ "KEY_RIGHT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6504370d9c6391e1a9da6a1a529b089d", null ],
      [ "KEY_DOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa9cdac7967bf7d88fdb761138a2a3416", null ],
      [ "KEY_PAGEUP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5d9c9ba1d8f2c6f6737db37d3f449071", null ],
      [ "KEY_PAGEDOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5996c34d86df2b3c1be741aeb35bdbc4", null ],
      [ "KEY_SELECT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3b37a163628bc7015aac5efab4a66ef5", null ],
      [ "KEY_PRINT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf6ff54b9651ca18045e4000c2d26f790", null ],
      [ "KEY_ENTER", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba2a662d23aadd7106a3a2afdfd5d426ed", null ],
      [ "KEY_SNAPSHOT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bacc39d60a35433541177dbd7bf01a8257", null ],
      [ "KEY_INSERT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba26f2c18a3a0a7eabf7bd11f0ec93be78", null ],
      [ "KEY_DELETE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae7a3a4540031b038014294aa6743a7a4", null ],
      [ "KEY_HELP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad729e81b40a3acb64b5a40b7fa459b09", null ],
      [ "KEY_NUMPAD0", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba55aef83f557c4ed24e2847d38ea292b3", null ],
      [ "KEY_NUMPAD1", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba681b5574363c5d5a463af7e514172292", null ],
      [ "KEY_NUMPAD2", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba779490ca3da209736187a912cd8382dc", null ],
      [ "KEY_NUMPAD3", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae58753ec4558e7b68f4aa07ed97d50d7", null ],
      [ "KEY_NUMPAD4", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba744226502b73227ed219a5142c232126", null ],
      [ "KEY_NUMPAD5", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba906fbf3011cae4b931d6fe6126147a82", null ],
      [ "KEY_NUMPAD6", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bac4e7f0a72c3594aa3d5b83f61b714e3f", null ],
      [ "KEY_NUMPAD7", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bae6d134db5bf54ae1d4b29f8a2cca8889", null ],
      [ "KEY_NUMPAD8", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba258d226c87d8446423d3214a59eb498b", null ],
      [ "KEY_NUMPAD9", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6ab9d27201ffbdccabde9f5a0e9dedd9", null ],
      [ "KEY_MULTIPLY", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa7ccd4f6c9a10fe36e0e7bd28d15bea3", null ],
      [ "KEY_ADD", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba88535ed64ae437ce31620dcb62c66c9e", null ],
      [ "KEY_SEPARATOR", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba79459423b8bbe9f70949f464cd7a27ae", null ],
      [ "KEY_SUBTRACT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf6ba424919235c2cbbac7184e3625395", null ],
      [ "KEY_DECIMAL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bafce663586a7e53223158c5f4ce6033fc", null ],
      [ "KEY_DIVIDE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba36a890023ae628d5c36ca010edffc59c", null ],
      [ "KEY_F1", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bafcf70bc39c0032de8a1c6452ac9860a5", null ],
      [ "KEY_F2", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba87897fd25282941e1a9bf72b9f64559a", null ],
      [ "KEY_F3", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba965c99b1f4fc05cec09ef61b0af8e74a", null ],
      [ "KEY_F4", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba01bce78a73ad136a7b42941297aff373", null ],
      [ "KEY_F5", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6a69ea34f5d1372692bf040637e57c8f", null ],
      [ "KEY_F6", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba247a20a9998f080827dd34004abc2f9a", null ],
      [ "KEY_F7", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba34a07203a0a4f3e996b44e9a4fcfd1c6", null ],
      [ "KEY_F8", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba9eaf4e9e3d8451fd1332c013d12c1375", null ],
      [ "KEY_F9", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba160e82eea885870bfa4924c27040cd7f", null ],
      [ "KEY_F10", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba3b922025c26b38585ab140c7e40b291c", null ],
      [ "KEY_F11", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bad54743bc4e7f9279abf671cc2a091ce1", null ],
      [ "KEY_F12", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba835f8397baa58fd73ff9c268d6458add", null ],
      [ "KEY_NUMLOCK", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa98feaa9c2c57dc8e7b04cb8fddc1a61", null ],
      [ "KEY_SCROLL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba10db988ee4f813d95a5b7cd2f96e3c48", null ],
      [ "KEY_SHIFT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba7d538b177ab06797012e9ffb1449acd9", null ],
      [ "KEY_CONTROL", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba48f64be40a1a166f83ec1cab14da6bdc", null ],
      [ "KEY_ALT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf22ac608afcf783bb841f664a2620ca6", null ],
      [ "KEY_EQUALS", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf97f0846e149da44bbf962fa75680809", null ],
      [ "KEY_CONTEXTMENU", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba1992687fd833d3503080861864624e25", null ],
      [ "KEY_MEDIA_PLAY", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba6322842e54ea558c670690f2715b45fb", null ],
      [ "KEY_MEDIA_STOP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baad3b9b6fd66ddf211586428be4479c43", null ],
      [ "KEY_MEDIA_PREV", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba29d798af827489cf5ab68c378b8a7ac8", null ],
      [ "KEY_MEDIA_NEXT", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bac80fc1b18bda12f7dfccbbe1b012798b", null ],
      [ "KEY_VOLUME_UP", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baedbb585f9e7ee87263a250c91542fb02", null ],
      [ "KEY_VOLUME_DOWN", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba2304f457aba66febcf852dbf1cbae8b0", null ],
      [ "KEY_F13", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba29161713f30649423d0ddefa16028396", null ],
      [ "KEY_F14", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba7a39de2eb466cf269a7a34d0377cf326", null ],
      [ "KEY_F15", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba57efdf8b5659ceaf5bda4be62e65ab56", null ],
      [ "KEY_F16", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baabf57281e043880eb269a6a72368aca5", null ],
      [ "KEY_F17", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba5ce646467129e626c1ec8888f80045ed", null ],
      [ "KEY_F18", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22bab6e856fc1ebc35abda65fd30fe9deeca", null ],
      [ "KEY_F19", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baa385ff09ff5f05a4fedb1e75570baa8b", null ],
      [ "KEY_SUPER", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22baf6db7ad5110a115d774dd8d74d333a42", null ],
      [ "VKEY_FIRST_CODE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba0abb06f320e406fbe76c08b2f5909ad6", null ],
      [ "VKEY_LAST_CODE", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba219b7884c92935dc6365a7fec8b55bcf", null ],
      [ "VKEY_FIRST_ASCII", "keycodes_8h.html#a9380117707cebcb5a3cd9fa8b960e22ba39f030dbc1bfdb4a14a310acc744178f", null ]
    ] ],
    [ "KeyModifier", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493d", [
      [ "kShiftKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da7dee5096e7803ac26cee7abe740d777d", null ],
      [ "kAlternateKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da8779d8eaee888493c6c5db7acc5d4a0a", null ],
      [ "kCommandKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da111880e47a70791b129ec7a46f988078", null ],
      [ "kControlKey", "keycodes_8h.html#a743f60968fa58cdae68b31a1a3eb493da6bd5ac36e7d960d29783e07406f3b15c", null ]
    ] ],
    [ "VirtualKeyCodeToChar", "keycodes_8h.html#a862d540e903360c185899756ea6f8fa6", null ],
    [ "CharToVirtualKeyCode", "keycodes_8h.html#a826c154067a1494875f963d77bbee8ca", null ],
    [ "isModifierOnlyKey", "keycodes_8h.html#ad183c365a06b5560e86a61439e756a19", null ]
];
